@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,5 +18,5 @@ public:
     void addSummary(const QString &name);
 
 private:
-    QTextEdit *mTextEdit = nullptr;
+    QTextEdit *const mTextEdit;
 };
